Molecules
=========

.. note::
    The molecules module requires optional dependencies. Install with the ``molecules`` feature to use this module.

.. currentmodule:: flowgym.molecules

.. autosummary::
    :toctree: generated/
    :template: class.rst
    :nosignatures:

    FlowMolBaseModel
    QM9BaseModel
    GEOMBaseModel
    MoleculeReward
    BatchedMoleculeReward
    DipoleMomentReward
    TargetDipoleMomentReward
    ProteinDockingReward
    QEDReward
    ValidityReward
